@@ -13,8 +13,12 @@ class CoopBarNode(template.Node):
         request = context.get("request", None)
         commands = CoopBar().get_commands(request, context)
         if commands: #hide admin-bar if nothing to display
+            context_dict = {'commands': commands}
+            for var_name in ('article', 'object'):
+                var = context.get(var_name, None)
+                context_dict[var_name] = var
             t = get_template("coop_bar.html")
-            return t.render(Context({'commands': commands}))
+            return t.render(Context(context_dict))
         return u''
 
 @register.tag
